pub enum EvaluationState {
Pending,
Evaluating,
Verdict(EvaluationVerdict),
Stale,
Rework,
}Expand description
Lifecycle of an evaluation report.
Variants
Pending
Claim is awaiting an independent evaluator.
Evaluating
Evaluator is inspecting the exact subject.
Verdict(EvaluationVerdict)
A report has been accepted for the current subject.
Stale
Subject changed after a report and the prior verdict no longer certifies it.
Rework
Rework is required before a new claim can be submitted.