pub struct ToolResult {
pub content: String,
pub is_error: bool,
pub continuations: Vec<ToolContinuation>,
}Expand description
The result of executing a tool.
Fields
content: StringThe output content produced by the tool.
is_error: boolWhether the execution resulted in an error.
continuations: Vec<ToolContinuation>Runtime-only continuation hints for later tool presentation.
Implementations
Sourceimpl ToolResult
impl ToolResult
Sourcepub fn success(content: impl Into<String>) -> Self
pub fn success(content: impl Into<String>) -> Self
Creates a successful tool result with the given content.
Sourcepub fn error(content: impl Into<String>) -> Self
pub fn error(content: impl Into<String>) -> Self
Creates an error tool result with the given error message.
Sourcepub fn with_continuation(self, continuation: ToolContinuation) -> Self
pub fn with_continuation(self, continuation: ToolContinuation) -> Self
Adds one runtime continuation hint to this tool result.